==> recup_app_storybook-1.0.0%2B1.tar.gz: lib/stories/cards/association/association_widget_story.dart <==
import 'dart:js';

import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:recup_app_storybook/stories/cards/association/association_widget.dart';
import 'package:recup_app_storybook/stories/default_storie.dart';
import 'package:recup_app_storybook/theme/colors.dart';
import 'package:storybook_flutter/storybook_flutter.dart';

class AssociationWidgetStory extends Story {
  final theme = ValueNotifier(ThemeMode.system);

  AssociationWidgetStory()
      : super(
            name: 'AssociationWidgetStory',
            builder: (context) => DefaultStory(body: AssociationWidget()));

  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width;
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Card(
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(15.0),
        ),
        color: color16,
        child: SizedBox(
          width: 176,
          height: 300,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Container(
                width: width,
                height: 180,
                decoration: const BoxDecoration(
                  image: DecorationImage(
                    fit: BoxFit.fill,
                    image: AssetImage("assets/fundo3.png"),
                  ),
                  borderRadius: BorderRadius.all(
                    Radius.circular(15.0),
                  ),
                ),
              ),
              const SizedBox(height: 15),
              Padding(
                padding: const EdgeInsets.only(left: 13, right: 13),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    const Text(
                      "League contre le cancer",
                      style: TextStyle(
                          color: color8,
                          fontSize: 12,
                          fontWeight: FontWeight.w600,
                          fontFamily: "Poppins"),
                    ),
                    Container(
                      child: RichText(
                        text: const TextSpan(
                          children: <TextSpan>[
                            TextSpan(
                                text: " 50 ",
                                style: TextStyle(
                                    color: color1,
                                    fontSize: 13,
                                    fontWeight: FontWeight.w600,
                                    fontFamily: "Poppins")),
                            TextSpan(
                              text: "following",
                              style: TextStyle(
                                  color: color1,
                                  fontSize: 13,
                                  fontWeight: FontWeight.w400,
                                  fontFamily: "Poppins"),
                            ),
                          ],
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              Padding(
                padding: const EdgeInsets.only(left: 13),
                child: SizedBox(
                  width: width * .63,
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      RichText(
                        text: const TextSpan(
                          children: <TextSpan>[
                            TextSpan(
                                text: "Seine Maritime",
                                style: TextStyle(
                                    color: color15,
                                    fontSize: 12,
                                    fontWeight: FontWeight.w400,
                                    fontFamily: "Poppins")),
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
              ),
              Padding(
                padding: const EdgeInsets.only(left: 13, right: 13),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    ElevatedButton(
                      onPressed: () {},
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          SvgPicture.asset("assets/icons/white/up.svg",
                              height: 11, width: 11),
                          const SizedBox(width: 5.0),
                          const Text(
                            'Donate',
                            style: TextStyle(
                                color: color8,
                                fontSize: 13,
                                fontWeight: FontWeight.w600,
                                fontFamily: "Poppins"),
                          ),
                        ],
                      ),
                      style: ElevatedButton.styleFrom(
                        minimumSize: Size.zero,
                        padding: EdgeInsets.zero,
                        primary: color1,
                        fixedSize: const Size(96, 25),
                        shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(50),
                        ),
                      ),
                    ),
                    Image.asset(
                      "assets/person.png",
                      height: 35,
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> recup_app_storybook-1.0.1%2B1.tar.gz: lib/stories/cards/association/association_widget_story.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:recup_app_storybook/stories/cards/association/association_widget.dart';
import 'package:recup_app_storybook/stories/default_storie.dart';

import 'package:storybook_flutter/storybook_flutter.dart';

class AssociationWidgetStory extends Story {
  final theme = ValueNotifier(ThemeMode.system);

  AssociationWidgetStory()
      : super(
            name: 'Card/AssociationWidgetStory',
            builder: (context) => DefaultStory(body: AssociationWidget()));

  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width;
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Card(
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(15.0),
        ),
        color: Colors.red,
        child: SizedBox(
          width: 176,
          height: 300,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Container(
                width: width,
                height: 180,
                decoration: const BoxDecoration(
                  image: DecorationImage(
                    fit: BoxFit.fill,
                    image: AssetImage("assets/fundo3.png"),
                  ),
                  borderRadius: BorderRadius.all(
                    Radius.circular(15.0),
                  ),
                ),
              ),
              const SizedBox(height: 15),
              Padding(
                padding: const EdgeInsets.only(left: 13, right: 13),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    const Text(
                      "League contre le cancer",
                      style: TextStyle(
                          color: Colors.red,
                          fontSize: 12,
                          fontWeight: FontWeight.w600,
                          fontFamily: "Poppins"),
                    ),
                    Container(
                      child: RichText(
                        text: const TextSpan(
                          children: <TextSpan>[
                            TextSpan(
                                text: " 50 ",
                                style: TextStyle(
                                    color: Colors.red,
                                    fontSize: 13,
                                    fontWeight: FontWeight.w600,
                                    fontFamily: "Poppins")),
                            TextSpan(
                              text: "following",
                              style: TextStyle(
                                  color: Colors.red,
                                  fontSize: 13,
                                  fontWeight: FontWeight.w400,
                                  fontFamily: "Poppins"),
                            ),
                          ],
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              Padding(
                padding: const EdgeInsets.only(left: 13),
                child: SizedBox(
                  width: width * .63,
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      RichText(
                        text: const TextSpan(
                          children: <TextSpan>[
                            TextSpan(
                                text: "Seine Maritime",
                                style: TextStyle(
                                    color: Colors.red,
                                    fontSize: 12,
                                    fontWeight: FontWeight.w400,
                                    fontFamily: "Poppins")),
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
              ),
              Padding(
                padding: const EdgeInsets.only(left: 13, right: 13),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    ElevatedButton(
                      onPressed: () {},
                      style: ElevatedButton.styleFrom(
                        minimumSize: Size.zero,
                        padding: EdgeInsets.zero,
                        primary: Colors.red,
                        fixedSize: const Size(96, 25),
                        shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(50),
                        ),
                      ),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          SvgPicture.asset("assets/icons/white/up.svg",
                              height: 11, width: 11),
                          const SizedBox(width: 5.0),
                          const Text(
                            'Donate',
                            style: TextStyle(
                                color: Colors.red,
                                fontSize: 13,
                                fontWeight: FontWeight.w600,
                                fontFamily: "Poppins"),
                          ),
                        ],
                      ),
                    ),
                    Image.asset(
                      "assets/person.png",
                      height: 35,
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
